@@ -613,6 +613,7 @@ void on_about(GtkMenuItem *menuitem,
                                 "Tao Klerks <tao@klerks.biz>",
                                 "Tobias Schönberg <tobias47n9e@gmail.com>",
                                 "Yuri D'Elia <yuri.delia@eurac.edu>",
+				"Julián Unrrein <junrrein@gmail.com>",
                                  NULL };
     gtk_show_about_dialog (NULL,
 			   "program-name", "Gromit-MPX",
@@ -622,7 +623,7 @@ void on_about(GtkMenuItem *menuitem,
 			   "version", VERSION,
 			   "website", "https://github.com/bk138/gromit-mpx",
 			   "authors", authors,
-			   "copyright", "Copyright 2000 Simon Budig, 2009-2018 Christian Beier",
+			   "copyright", "Copyright 2000 Simon Budig, 2009-2020 Christian Beier",
 			   "license-type", GTK_LICENSE_GPL_2_0,
 			   NULL);
 }
@@ -648,7 +649,10 @@ void on_intro(GtkMenuItem *menuitem,
 					  "Its main use is for making presentations of some application. Normally,\n"
 					  "you would have to move the mouse pointer around the point of interest\n"
 					  "until hopefully everybody noticed it.  With Gromit-MPX, you can draw\n"
-					  "everywhere onto the screen, highlighting some button or area.");
+					  "everywhere onto the screen, highlighting some button or area.\n\n"
+                                          "If you happen to enjoy using Gromit-MPX, please consider supporting\n"
+					  "its development by using one of the donation options on the project's\n"
+					  "website.");
     gtk_assistant_append_page (GTK_ASSISTANT (assistant), widgetOne);
     gtk_assistant_set_page_title (GTK_ASSISTANT (assistant), widgetOne, "Gromit-MPX - What is it?");
     gtk_assistant_set_page_type (GTK_ASSISTANT (assistant), widgetOne, GTK_ASSISTANT_PAGE_INTRO);
